=======================================
``psyclone.tests.psyir.backend.c_test``
=======================================

.. automodule:: psyclone.tests.psyir.backend.c_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.c_test
